@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,11 +23,13 @@
 #include "AddPrinterAssistant.h"
 
 #include <KCupsRequest.h>
+#include <KWindowSystem>
 
 #include <QPointer>
-#include <QDebug>
 
-#include <KWindowSystem>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(PM_ADD_PRINTER)
 
 AddPrinter::AddPrinter(int &argc, char **argv) :
     QApplication(argc, argv)
@@ -41,14 +43,14 @@ AddPrinter::~AddPrinter()
 
 void AddPrinter::addPrinter(qulonglong wid)
 {
-    AddPrinterAssistant *wizard = new AddPrinterAssistant();
+    auto wizard = new AddPrinterAssistant();
     wizard->initAddPrinter();
     show(wizard, wid);
 }
 
 void AddPrinter::addClass(qulonglong wid)
 {
-    AddPrinterAssistant *wizard = new AddPrinterAssistant();
+    auto wizard = new AddPrinterAssistant();
     wizard->initAddClass();
     show(wizard, wid);
 }
@@ -57,19 +59,20 @@ void AddPrinter::changePPD(qulonglong wid, const QString &name)
 {
     // Fist we need to get the printer attributes
     QPointer<KCupsRequest> request = new KCupsRequest;
-    QStringList attr;
-    attr << KCUPS_PRINTER_TYPE; // needed to know if it's a remote printer
-    attr << KCUPS_PRINTER_MAKE_AND_MODEL;
-    attr << KCUPS_DEVICE_URI;
+    const QStringList attr({
+                               KCUPS_PRINTER_TYPE, // needed to know if it's a remote printer
+                               KCUPS_PRINTER_MAKE_AND_MODEL,
+                               KCUPS_DEVICE_URI
+                           });
     request->getPrinterAttributes(name, false, attr);
     request->waitTillFinished();
     if (request) {
         if (!request->hasError() && request->printers().size() == 1) {
-            KCupsPrinter printer = request->printers().first();
+            const KCupsPrinter printer = request->printers().first();
             if (printer.type() & CUPS_PRINTER_REMOTE) {
-                qWarning() << "Ignoring request, can not change PPD of remote printer" << name;
+                qCWarning(PM_ADD_PRINTER) << "Ignoring request, can not change PPD of remote printer" << name;
             } else {
-                AddPrinterAssistant *wizard = new AddPrinterAssistant();
+                auto wizard = new AddPrinterAssistant();
                 wizard->initChangePPD(name, printer.deviceUri(), printer.makeAndModel());
                 show(wizard, wid);
             }
@@ -99,7 +102,7 @@ void AddPrinter::newPrinterFromDevice(qulonglong wid, const QString &name, const
     //        printer = "HP PSC 1400 series";
     //        deviceId = "MFG:HP;MDL:PSC 1400 series;DES:;CMD:LDL,MLC,PML,DYN;";
 
-    AddPrinterAssistant *wizard = new AddPrinterAssistant();
+    auto wizard = new AddPrinterAssistant();
     wizard->initAddPrinter(name, device_id);
     show(wizard, wid);
 }
@@ -110,3 +113,5 @@ void AddPrinter::show(QWidget *widget, qulonglong wid) const
     KWindowSystem::forceActiveWindow(widget->winId());
     KWindowSystem::setMainWindow(widget, wid);
 }
+
+#include "moc_AddPrinter.cpp"
