@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,20 +36,15 @@
 #include <KSharedConfig>
 #include <KWindowConfig>
 
-AddPrinterAssistant::AddPrinterAssistant() :
-    KAssistantDialog(),
-    m_devicesPage(0),
-    m_chooseClassPage(0),
-    m_choosePPDPage(0),
-    m_addPrinterPage(0)
+AddPrinterAssistant::AddPrinterAssistant()
 {
     setWindowTitle(i18nc("@title:window", "Add a New Printer"));
-    setWindowIcon(QIcon::fromTheme("printer"));
+    setWindowIcon(QIcon::fromTheme(QLatin1String("printer")));
     buttonBox()->removeButton(buttonBox()->button(QDialogButtonBox::Cancel));
     // Needed so we have our dialog size saved
     setAttribute(Qt::WA_DeleteOnClose);
 
-    QPushButton * helpButton = buttonBox()->addButton(QDialogButtonBox::Help);
+    QPushButton *helpButton = buttonBox()->addButton(QDialogButtonBox::Help);
     // Configure the help button to be flat, disabled and empty
     helpButton->setFlat(true);
     helpButton->setEnabled(false);
@@ -58,21 +53,20 @@ AddPrinterAssistant::AddPrinterAssistant() :
 
     // Setup the busy cursor
     m_busySeq = new KPixmapSequenceOverlayPainter(this);
-    m_busySeq->setSequence(KIconLoader::global()->loadPixmapSequence("process-working", KIconLoader::SizeSmallMedium));
+    m_busySeq->setSequence(KIconLoader::global()->loadPixmapSequence(QLatin1String("process-working"), KIconLoader::SizeSmallMedium));
     m_busySeq->setAlignment(Qt::AlignHCenter | Qt::AlignBottom);
     m_busySeq->setWidget(helpButton);
 
-    connect(finishButton(), SIGNAL(clicked()),
-            this, SLOT(slotFinishButtonClicked()));
+    connect(finishButton(), &QPushButton::clicked, this, &AddPrinterAssistant::slotFinishButtonClicked);
 
     // Restore the dialog size
-    KConfigGroup configGroup(KSharedConfig::openConfig("print-manager"), "AddPrinterAssistant");
+    KConfigGroup configGroup(KSharedConfig::openConfig(QLatin1String("print-manager")), "AddPrinterAssistant");
     KWindowConfig::restoreWindowSize(windowHandle(), configGroup);
 }
 
 AddPrinterAssistant::~AddPrinterAssistant()
 {
-    KConfigGroup configGroup(KSharedConfig::openConfig("print-manager"), "AddPrinterAssistant");
+    KConfigGroup configGroup(KSharedConfig::openConfig(QLatin1String("print-manager")), "AddPrinterAssistant");
     KWindowConfig::saveWindowSize(windowHandle(), configGroup);
 }
 
@@ -80,8 +74,9 @@ void AddPrinterAssistant::initAddPrinter(const QString &printer, const QString &
 {
     // setup our hash args with the information if we are
     // adding a new printer or a class
-    QVariantHash args;
-    args[ADDING_PRINTER] = true;
+    QVariantHash args({
+                          {ADDING_PRINTER, true}
+                      });
 
     KPageWidgetItem *currentPage;
     if (deviceId.isEmpty()) {
@@ -112,9 +107,10 @@ void AddPrinterAssistant::initAddClass()
 {
     // setup our hash args with the information if we are
     // adding a new printer or a class
-    QVariantHash args;
-    args[ADDING_PRINTER] = false;
-    args[KCUPS_DEVICE_LOCATION] = QHostInfo::localHostName();
+    const QVariantHash args({
+                                {ADDING_PRINTER, false},
+                                {KCUPS_DEVICE_LOCATION, QHostInfo::localHostName()}
+                            });
 
     KPageWidgetItem *currentPage;
     m_chooseClassPage = new KPageWidgetItem(new PageChoosePrinters(args), i18nc("@title:window", "Configure your connection"));
@@ -132,11 +128,12 @@ void AddPrinterAssistant::initChangePPD(const QString &printer, const QString &d
 {
     // setup our hash args with the information if we are
     // adding a new printer or a class
-    QVariantHash args;
-    args[ADDING_PRINTER] = true;
-    args[KCUPS_DEVICE_URI] = deviceUri;
-    args[KCUPS_PRINTER_NAME] = printer;
-    args[KCUPS_PRINTER_MAKE_AND_MODEL] = makeAndModel;
+    const QVariantHash args({
+                                {ADDING_PRINTER, true},
+                                {KCUPS_DEVICE_URI, deviceUri},
+                                {KCUPS_PRINTER_NAME, printer},
+                                {KCUPS_PRINTER_MAKE_AND_MODEL, makeAndModel}
+                            });
 
     m_choosePPDPage = new KPageWidgetItem(new PageChoosePPD(args), i18nc("@title:window", "Pick a Driver"));
     addPage(m_choosePPDPage);
@@ -146,8 +143,7 @@ void AddPrinterAssistant::initChangePPD(const QString &printer, const QString &d
 void AddPrinterAssistant::back()
 {
     KAssistantDialog::back();
-    GenericPage *currPage;
-    currPage = qobject_cast<GenericPage*>(currentPage()->widget());
+    auto currPage = qobject_cast<GenericPage*>(currentPage()->widget());
     enableNextButton(currPage->canProceed());
     if (!qobject_cast<GenericPage*>(currentPage()->widget())->isValid()) {
         back();
@@ -166,7 +162,7 @@ void AddPrinterAssistant::next(KPageWidgetItem *currentPage)
     // we don't set (or even unset values),
     // and we only call setValues on the next page if
     // the currentPage() has changes.
-    QVariantHash args = qobject_cast<GenericPage*>(currentPage->widget())->values();
+    const QVariantHash args = qobject_cast<GenericPage*>(currentPage->widget())->values();
     if (currentPage == m_devicesPage) {
         qobject_cast<GenericPage*>(m_choosePPDPage->widget())->setValues(args);
         setCurrentPage(m_choosePPDPage);
@@ -182,19 +178,19 @@ void AddPrinterAssistant::setCurrentPage(KPageWidgetItem *page)
     // it up, if not call next with it so we can find the next page
     if (qobject_cast<GenericPage*>(page->widget())->isValid()) {
         KAssistantDialog::setCurrentPage(page);
-        GenericPage *currPage = qobject_cast<GenericPage*>(currentPage()->widget());
-        GenericPage *nextPage = qobject_cast<GenericPage*>(page->widget());
+        auto currPage = qobject_cast<GenericPage*>(currentPage()->widget());
+        auto nextPage = qobject_cast<GenericPage*>(page->widget());
         // Disconnect the current page slots
-        disconnect(currPage, SIGNAL(allowProceed(bool)), this, SLOT(enableNextButton(bool)));
-        disconnect(currPage, SIGNAL(allowProceed(bool)), this, SLOT(enableFinishButton(bool)));
-        disconnect(currPage, SIGNAL(startWorking()), m_busySeq, SLOT(start()));
-        disconnect(currPage, SIGNAL(stopWorking()), m_busySeq, SLOT(stop()));
-        disconnect(currPage, SIGNAL(proceed()), this, SLOT(next()));
+        disconnect(currPage, &GenericPage::allowProceed, this, &AddPrinterAssistant::enableNextButton);
+        disconnect(currPage, &GenericPage::allowProceed, this, &AddPrinterAssistant::enableFinishButton);
+        disconnect(currPage, &GenericPage::proceed, this, static_cast<void(AddPrinterAssistant::*)()>(&AddPrinterAssistant::next));
+        disconnect(currPage, &GenericPage::startWorking, m_busySeq, &KPixmapSequenceOverlayPainter::start);
+        disconnect(currPage, &GenericPage::stopWorking, m_busySeq, &KPixmapSequenceOverlayPainter::stop);
 
         // Connect next page signals
-        connect(currPage, SIGNAL(startWorking()), m_busySeq, SLOT(start()));
-        connect(currPage, SIGNAL(stopWorking()), m_busySeq, SLOT(stop()));
-        connect(nextPage, SIGNAL(proceed()), this, SLOT(next()));
+        connect(nextPage, &GenericPage::startWorking, m_busySeq, &KPixmapSequenceOverlayPainter::start);
+        connect(nextPage, &GenericPage::stopWorking, m_busySeq, &KPixmapSequenceOverlayPainter::stop);
+        connect(nextPage, &GenericPage::proceed, this, static_cast<void(AddPrinterAssistant::*)()>(&AddPrinterAssistant::next));
 
         // check the working property
         if (nextPage->isWorking()) {
@@ -205,11 +201,11 @@ void AddPrinterAssistant::setCurrentPage(KPageWidgetItem *page)
 
         // When ChangePPD() is called addPrinterPage is zero
         if (page == m_addPrinterPage || m_addPrinterPage == 0) {
-            connect(nextPage, SIGNAL(allowProceed(bool)), this, SLOT(enableFinishButton(bool)));
+            connect(nextPage, &GenericPage::allowProceed, this, &AddPrinterAssistant::enableFinishButton);
             enableNextButton(false);
             enableFinishButton(nextPage->canProceed());
         } else {
-            connect(nextPage, SIGNAL(allowProceed(bool)), this, SLOT(enableNextButton(bool)));
+            connect(nextPage, &GenericPage::allowProceed, this, &AddPrinterAssistant::enableNextButton);
             enableNextButton(nextPage->canProceed());
         }
     } else {
@@ -227,7 +223,7 @@ void AddPrinterAssistant::showEvent(QShowEvent *event)
 
 void AddPrinterAssistant::slotFinishButtonClicked()
 {
-    GenericPage *page = qobject_cast<GenericPage*>(currentPage()->widget());
+    auto page = qobject_cast<GenericPage*>(currentPage()->widget());
     enableFinishButton(false);
     if (page->finishClicked()) {
         //KAssistantDialog::slotButtonClicked(button); // FIXME next() really?
@@ -246,3 +242,5 @@ void AddPrinterAssistant::enableFinishButton(bool enable)
 {
     finishButton()->setEnabled(enable);
 }
+
+#include "moc_AddPrinterAssistant.cpp"
