@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
- *   dantti12@gmail.com                                                    *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti <dantti12@gmail.com>      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -34,13 +33,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <QStringBuilder>
-
-JobModel::JobModel(QObject *parent) :
-    QStandardItemModel(parent),
-    m_jobRequest(0),
-    m_whichjobs(CUPS_WHICHJOBS_ACTIVE),
-    m_parentId(0)
+JobModel::JobModel(QObject *parent) : QStandardItemModel(parent)
 {
     setHorizontalHeaderItem(ColStatus,        new QStandardItem(i18n("Status")));
     setHorizontalHeaderItem(ColName,          new QStandardItem(i18n("Name")));
@@ -54,85 +47,44 @@ JobModel::JobModel(QObject *parent) :
     setHorizontalHeaderItem(ColPrinter,       new QStandardItem(i18n("Printer")));
     setHorizontalHeaderItem(ColFromHost,      new QStandardItem(i18n("From Hostname")));
 
-    // Setup the attributes we want from jobs
-    m_jobAttributes << KCUPS_JOB_ID;
-    m_jobAttributes << KCUPS_JOB_NAME;
-    m_jobAttributes << KCUPS_JOB_K_OCTETS;
-    m_jobAttributes << KCUPS_JOB_K_OCTETS_PROCESSED;
-    m_jobAttributes << KCUPS_JOB_STATE;
-    m_jobAttributes << KCUPS_TIME_AT_COMPLETED;
-    m_jobAttributes << KCUPS_TIME_AT_CREATION;
-    m_jobAttributes << KCUPS_TIME_AT_PROCESSING;
-    m_jobAttributes << KCUPS_JOB_PRINTER_URI;
-    m_jobAttributes << KCUPS_JOB_ORIGINATING_USER_NAME;
-    m_jobAttributes << KCUPS_JOB_ORIGINATING_HOST_NAME;
-    m_jobAttributes << KCUPS_JOB_MEDIA_PROGRESS;
-    m_jobAttributes << KCUPS_JOB_MEDIA_SHEETS;
-    m_jobAttributes << KCUPS_JOB_MEDIA_SHEETS_COMPLETED;
-    m_jobAttributes << KCUPS_JOB_PRINTER_STATE_MESSAGE;
-    m_jobAttributes << KCUPS_JOB_PRESERVED;
-
-    QHash<int, QByteArray> roles = roleNames();
-    roles[RoleJobId] = "jobId";
-    roles[RoleJobState] = "jobState";
-    roles[RoleJobName] = "jobName";
-    roles[RoleJobPages] = "jobPages";
-    roles[RoleJobSize] = "jobSize";
-    roles[RoleJobOwner] = "jobOwner";
-    roles[RoleJobCreatedAt] = "jobCreatedAt";
-    roles[RoleJobIconName] = "jobIconName";
-    roles[RoleJobCancelEnabled] = "jobCancelEnabled";
-    roles[RoleJobHoldEnabled] = "jobHoldEnabled";
-    roles[RoleJobReleaseEnabled] = "jobReleaseEnabled";
-    roles[RoleJobRestartEnabled] = "jobRestartEnabled";
-    roles[RoleJobPrinter] = "jobPrinter";
-    roles[RoleJobOriginatingHostName] = "jobFrom";
-    setRoleNames(roles);
+    m_roles = QStandardItemModel::roleNames();
+    m_roles[RoleJobId] = "jobId";
+    m_roles[RoleJobState] = "jobState";
+    m_roles[RoleJobName] = "jobName";
+    m_roles[RoleJobPages] = "jobPages";
+    m_roles[RoleJobSize] = "jobSize";
+    m_roles[RoleJobOwner] = "jobOwner";
+    m_roles[RoleJobCreatedAt] = "jobCreatedAt";
+    m_roles[RoleJobIconName] = "jobIconName";
+    m_roles[RoleJobCancelEnabled] = "jobCancelEnabled";
+    m_roles[RoleJobHoldEnabled] = "jobHoldEnabled";
+    m_roles[RoleJobReleaseEnabled] = "jobReleaseEnabled";
+    m_roles[RoleJobRestartEnabled] = "jobRestartEnabled";
+    m_roles[RoleJobPrinter] = "jobPrinter";
+    m_roles[RoleJobOriginatingHostName] = "jobFrom";
 
     // This is emitted when a job change it's state
-    connect(KCupsConnection::global(),
-            SIGNAL(jobState(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)),
-            this,
-            SLOT(insertUpdateJob(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)));
+    connect(KCupsConnection::global(), &KCupsConnection::jobState, this, &JobModel::insertUpdateJob);
 
     // This is emitted when a job is created
-    connect(KCupsConnection::global(),
-            SIGNAL(jobCreated(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)),
-            this,
-            SLOT(insertUpdateJob(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)));
+    connect(KCupsConnection::global(), &KCupsConnection::jobCreated, this, &JobModel::insertUpdateJob);
 
     // This is emitted when a job is stopped
-    connect(KCupsConnection::global(),
-            SIGNAL(jobStopped(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)),
-            this,
-            SLOT(insertUpdateJob(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)));
+    connect(KCupsConnection::global(), &KCupsConnection::jobStopped, this, &JobModel::insertUpdateJob);
 
     // This is emitted when a job has it's config changed
-    connect(KCupsConnection::global(),
-            SIGNAL(jobConfigChanged(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)),
-            this,
-            SLOT(insertUpdateJob(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)));
+    connect(KCupsConnection::global(), &KCupsConnection::jobConfigChanged, this, &JobModel::insertUpdateJob);
 
     // This is emitted when a job change it's progress
-    connect(KCupsConnection::global(),
-            SIGNAL(jobProgress(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)),
-            this,
-            SLOT(insertUpdateJob(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)));
+    connect(KCupsConnection::global(), &KCupsConnection::jobProgress, this, &JobModel::insertUpdateJob);
 
     // This is emitted when a printer is removed
-    connect(KCupsConnection::global(),
-            SIGNAL(jobCompleted(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)),
-            this,
-            SLOT(jobCompleted(QString,QString,QString,uint,QString,bool,uint,uint,QString,QString,uint)));
+    connect(KCupsConnection::global(), &KCupsConnection::jobCompleted, this, &JobModel::jobCompleted);
 
-    connect(KCupsConnection::global(), SIGNAL(serverAudit(QString)),
-            SLOT(getJobs()));
-    connect(KCupsConnection::global(), SIGNAL(serverStarted(QString)),
-            SLOT(getJobs()));
-    connect(KCupsConnection::global(), SIGNAL(serverStopped(QString)),
-            SLOT(getJobs()));
-    connect(KCupsConnection::global(), SIGNAL(serverRestarted(QString)),
-            SLOT(getJobs()));
+    connect(KCupsConnection::global(), &KCupsConnection::serverAudit, this, &JobModel::getJobs);
+    connect(KCupsConnection::global(), &KCupsConnection::serverStarted, this, &JobModel::getJobs);
+    connect(KCupsConnection::global(), &KCupsConnection::serverStopped, this, &JobModel::getJobs);
+    connect(KCupsConnection::global(), &KCupsConnection::serverRestarted, this, &JobModel::getJobs);
 }
 
 void JobModel::setParentWId(WId parentId)
@@ -195,22 +147,39 @@ void JobModel::getJobs()
     }
 
     m_jobRequest = new KCupsRequest;
-    connect(m_jobRequest, SIGNAL(finished()), this, SLOT(getJobFinished()));
+    connect(m_jobRequest, &KCupsRequest::finished, this, &JobModel::getJobFinished);
 
-    m_jobRequest->getJobs(m_destName, false, m_whichjobs, m_jobAttributes);
+    const static QStringList attrs({
+                                       KCUPS_JOB_ID,
+                                       KCUPS_JOB_NAME,
+                                       KCUPS_JOB_K_OCTETS,
+                                       KCUPS_JOB_K_OCTETS_PROCESSED,
+                                       KCUPS_JOB_STATE,
+                                       KCUPS_TIME_AT_COMPLETED,
+                                       KCUPS_TIME_AT_CREATION,
+                                       KCUPS_TIME_AT_PROCESSING,
+                                       KCUPS_JOB_PRINTER_URI,
+                                       KCUPS_JOB_ORIGINATING_USER_NAME,
+                                       KCUPS_JOB_ORIGINATING_HOST_NAME,
+                                       KCUPS_JOB_MEDIA_PROGRESS,
+                                       KCUPS_JOB_MEDIA_SHEETS,
+                                       KCUPS_JOB_MEDIA_SHEETS_COMPLETED,
+                                       KCUPS_JOB_PRINTER_STATE_MESSAGE,
+                                       KCUPS_JOB_PRESERVED
+                                   });
+    m_jobRequest->getJobs(m_destName, false, m_whichjobs, attrs);
 
     m_processingJob.clear();
 }
 
-void JobModel::getJobFinished()
+void JobModel::getJobFinished(KCupsRequest *request)
 {
-    KCupsRequest *request = static_cast<KCupsRequest *>(sender());
     if (request) {
         if (request->hasError()) {
             // clear the model after so that the proper widget can be shown
             clear();
         } else {
-            KCupsJobs jobs = request->jobs();
+            const KCupsJobs jobs = request->jobs();
             qCDebug(LIBKCUPS) << jobs.size();
             for (int i = 0; i < jobs.size(); ++i) {
                 if (jobs.at(i).state() == IPP_JOB_PROCESSING) {
@@ -313,7 +282,7 @@ void JobModel::insertJob(int pos, const KCupsJob &job)
     // insert the first column which has the job state and id
     QList<QStandardItem*> row;
     ipp_jstate_e jobState = job.state();
-    QStandardItem *statusItem = new QStandardItem(jobStatus(jobState));
+    auto statusItem = new QStandardItem(jobStatus(jobState));
     statusItem->setData(jobState, RoleJobState);
     statusItem->setData(job.id(), RoleJobId);
     statusItem->setData(job.name(), RoleJobName);
@@ -333,7 +302,7 @@ void JobModel::insertJob(int pos, const KCupsJob &job)
 
     QString pages = QString::number(job.pages());
     if (job.processedPages()) {
-        pages = QString::number(job.processedPages()) % QLatin1Char('/') % QString::number(job.processedPages());
+        pages = QString::number(job.processedPages()) + QLatin1Char('/') + QString::number(job.processedPages());
     }
     if (statusItem->data(RoleJobPages) != pages) {
         statusItem->setData(pages, RoleJobPages);
@@ -369,7 +338,7 @@ void JobModel::updateJob(int pos, const KCupsJob &job)
 
     QString pages = QString::number(job.pages());
     if (job.processedPages()) {
-        pages = QString::number(job.processedPages()) % QLatin1Char('/') % QString::number(job.processedPages());
+        pages = QString::number(job.processedPages()) + QLatin1Char('/') + QString::number(job.processedPages());
     }
     if (item(pos, ColStatus)->data(RoleJobPages) != pages) {
         item(pos, ColStatus)->setData(pages, RoleJobPages);
@@ -460,7 +429,7 @@ void JobModel::updateJob(int pos, const KCupsJob &job)
 
 QStringList JobModel::mimeTypes() const
 {
-    return QStringList("application/x-cupsjobs");
+    return { QStringLiteral("application/x-cupsjobs") };
 }
 
 Qt::DropActions JobModel::supportedDropActions() const
@@ -470,12 +439,12 @@ Qt::DropActions JobModel::supportedDropActions() const
 
 QMimeData* JobModel::mimeData(const QModelIndexList &indexes) const
 {
-    QMimeData *mimeData = new QMimeData();
+    auto mimeData = new QMimeData();
     QByteArray encodedData;
 
     QDataStream stream(&encodedData, QIODevice::WriteOnly);
 
-    foreach (const QModelIndex &index, indexes) {
+    for (const QModelIndex &index : indexes) {
         if (index.isValid() && index.column() == 0) {
             // serialize the jobId and fromDestName
             stream << data(index, RoleJobId).toInt()
@@ -484,7 +453,7 @@ QMimeData* JobModel::mimeData(const QModelIndexList &indexes) const
         }
     }
 
-    mimeData->setData("application/x-cupsjobs", encodedData);
+    mimeData->setData(QLatin1String("application/x-cupsjobs"), encodedData);
     return mimeData;
 }
 
@@ -501,11 +470,11 @@ bool JobModel::dropMimeData(const QMimeData *data,
         return true;
     }
 
-    if (!data->hasFormat("application/x-cupsjobs")) {
+    if (!data->hasFormat(QLatin1String("application/x-cupsjobs"))) {
         return false;
     }
 
-    QByteArray encodedData = data->data("application/x-cupsjobs");
+    QByteArray encodedData = data->data(QLatin1String("application/x-cupsjobs"));
     QDataStream stream(&encodedData, QIODevice::ReadOnly);
 
     bool ret = false;
@@ -538,6 +507,11 @@ bool JobModel::dropMimeData(const QMimeData *data,
     return ret;
 }
 
+QHash<int, QByteArray> JobModel::roleNames() const
+{
+    return m_roles;
+}
+
 KCupsRequest* JobModel::modifyJob(int row, JobAction action, const QString &newDestName, const QModelIndex &parent)
 {
     Q_UNUSED(parent)
@@ -559,7 +533,7 @@ KCupsRequest* JobModel::modifyJob(int row, JobAction action, const QString &newD
         return 0;
     }
 
-    KCupsRequest *request = new KCupsRequest;
+    auto request = new KCupsRequest;
     switch (action) {
     case Cancel:
         request->cancelJob(destName, jobId);
@@ -603,13 +577,13 @@ QString JobModel::jobStatus(ipp_jstate_e job_state)
   {
     case IPP_JOB_PENDING    : return i18n("Pending");
     case IPP_JOB_HELD       : return i18n("On hold");
-    case IPP_JOB_PROCESSING : return "-";
+    case IPP_JOB_PROCESSING : return QLatin1String("-");
     case IPP_JOB_STOPPED    : return i18n("Stopped");
     case IPP_JOB_CANCELED   : return i18n("Canceled");
     case IPP_JOB_ABORTED    : return i18n("Aborted");
     case IPP_JOB_COMPLETED  : return i18n("Completed");
   }
-  return "-";
+  return QLatin1String("-");
 }
 
 void JobModel::clear()
@@ -650,3 +624,5 @@ QString JobModel::processingJob() const
 {
     return m_processingJob;
 }
+
+#include "moc_JobModel.cpp"
