@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *   Copyright (C) 2012 Harald Sitter <sitter@kde.org>                     *
  *                                                                         *
@@ -28,7 +28,6 @@
 #include <config.h>
 
 #include <QCoreApplication>
-#include <QStringBuilder>
 #include <QDBusConnection>
 #include <QByteArray>
 #include <QMutexLocker>
@@ -117,8 +116,6 @@ void KCupsConnection::init()
 {
     // Creating the dialog before start() will make it run on the gui thread
     m_passwordDialog = new KCupsPasswordDialog;
-    m_subscriptionId = -1;
-    m_inited = false;
 
     // setup the DBus subscriptions
 
@@ -268,14 +265,16 @@ void KCupsConnection::init()
     m_renewTimer = new QTimer;
     m_renewTimer->setInterval(RENEW_INTERVAL*1000);
     m_renewTimer->moveToThread(this);
-    connect(m_renewTimer, SIGNAL(timeout()), this, SLOT(renewDBusSubscription()), Qt::DirectConnection);
+    connect(m_renewTimer, &QTimer::timeout,
+            this, static_cast<void(KCupsConnection::*)()>(&KCupsConnection::renewDBusSubscription), Qt::DirectConnection);
+
 
     // Creates the timer to merge updates on the DBus subscription
     m_subscriptionTimer = new QTimer;
     m_subscriptionTimer->setInterval(0);
     m_subscriptionTimer->setSingleShot(true);
     m_subscriptionTimer->moveToThread(this);
-    connect(m_subscriptionTimer, SIGNAL(timeout()), this, SLOT(updateSubscription()), Qt::DirectConnection);
+    connect(m_subscriptionTimer, &QTimer::timeout, this, &KCupsConnection::updateSubscription, Qt::DirectConnection);
 
     // Starts this thread
     start();
@@ -292,7 +291,7 @@ void KCupsConnection::run()
             m_serverUrl.setPort(631);
         }
 
-        cupsSetServer(m_serverUrl.authority().toUtf8());
+        cupsSetServer(qUtf8Printable(m_serverUrl.authority()));
     }
 
     // This is dead cool, cups will call the thread_password_cb()
@@ -331,7 +330,7 @@ ReturnArguments KCupsConnection::request(const KIppRequest &request, ipp_tag_t g
         response = NULL;
 
         response = request.sendIppRequest();
-    } while (retry(request.resource().toUtf8(), request.operation()));
+    } while (retry(qUtf8Printable(request.resource()), request.operation()));
 
     if (response && groupTag != IPP_TAG_ZERO) {
         ret = parseIPPVars(response, groupTag);
@@ -355,20 +354,20 @@ int KCupsConnection::renewDBusSubscription(int subscriptionId, int leaseDuration
         operation = IPP_CREATE_PRINTER_SUBSCRIPTION;
     }
 
-    KIppRequest request(operation, "/");
+    KIppRequest request(operation, QLatin1String("/"));
     request.addString(IPP_TAG_OPERATION, IPP_TAG_URI,
-                       KCUPS_PRINTER_URI, QLatin1String("/"));
+                      KCUPS_PRINTER_URI, QLatin1String("/"));
     request.addInteger(IPP_TAG_SUBSCRIPTION, IPP_TAG_INTEGER,
-                        KCUPS_NOTIFY_LEASE_DURATION, leaseDuration);
+                       KCUPS_NOTIFY_LEASE_DURATION, leaseDuration);
 
     if (operation == IPP_CREATE_PRINTER_SUBSCRIPTION) {
         // Add the "notify-events" values to the request
         request.addStringList(IPP_TAG_SUBSCRIPTION, IPP_TAG_KEYWORD,
                               KCUPS_NOTIFY_EVENTS, events);
         request.addString(IPP_TAG_SUBSCRIPTION, IPP_TAG_KEYWORD,
-                          KCUPS_NOTIFY_PULL_METHOD, "ippget");
+                          KCUPS_NOTIFY_PULL_METHOD, QLatin1String("ippget"));
         request.addString(IPP_TAG_SUBSCRIPTION, IPP_TAG_URI,
-                          KCUPS_NOTIFY_RECIPIENT_URI, "dbus://");
+                          KCUPS_NOTIFY_RECIPIENT_URI, QLatin1String("dbus://"));
     } else {
         request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER,
                            KCUPS_NOTIFY_SUBSCRIPTION_ID, subscriptionId);
@@ -425,8 +424,8 @@ void KCupsConnection::notifierConnect(const QString &signal, QObject *receiver,
 {
     QDBusConnection systemBus = QDBusConnection::systemBus();
     systemBus.connect(QString(),
-                      QLatin1String("/org/cups/cupsd/Notifier"),
-                      QLatin1String("org.cups.cupsd.Notifier"),
+                      QStringLiteral("/org/cups/cupsd/Notifier"),
+                      QStringLiteral("org.cups.cupsd.Notifier"),
                       signal,
                       receiver,
                       slot);
@@ -460,65 +459,65 @@ QString KCupsConnection::eventForSignal(const QMetaMethod & signal) const
 {
     // Server signals
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::serverAudit)) {
-        return DBUS_SERVER_AUDIT;
+        return QStringLiteral(DBUS_SERVER_AUDIT);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::serverStarted)) {
-        return DBUS_SERVER_STARTED;
+        return QStringLiteral(DBUS_SERVER_STARTED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::serverStopped)) {
-        return DBUS_SERVER_STOPPED;
+        return QStringLiteral(DBUS_SERVER_STOPPED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::serverRestarted)) {
-        return DBUS_SERVER_RESTARTED;
+        return QStringLiteral(DBUS_SERVER_RESTARTED);
     }
 
     // Printer signals
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerAdded)) {
-        return DBUS_PRINTER_ADDED;
+        return QStringLiteral(DBUS_PRINTER_ADDED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerDeleted)) {
-        return DBUS_PRINTER_DELETED;
+        return QStringLiteral(DBUS_PRINTER_DELETED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerFinishingsChanged)) {
-        return DBUS_PRINTER_FINISHINGS_CHANGED;
+        return QStringLiteral(DBUS_PRINTER_FINISHINGS_CHANGED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerMediaChanged)) {
-        return DBUS_PRINTER_MEDIA_CHANGED;
+        return QStringLiteral(DBUS_PRINTER_MEDIA_CHANGED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerModified)) {
-        return DBUS_PRINTER_MODIFIED;
+        return QStringLiteral(DBUS_PRINTER_MODIFIED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerRestarted)) {
-        return DBUS_PRINTER_RESTARTED;
+        return QStringLiteral(DBUS_PRINTER_RESTARTED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerShutdown)) {
-        return DBUS_PRINTER_SHUTDOWN;
+        return QStringLiteral(DBUS_PRINTER_SHUTDOWN);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerStateChanged)) {
-        return DBUS_PRINTER_STATE_CHANGED;
+        return QStringLiteral(DBUS_PRINTER_STATE_CHANGED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::printerStopped)) {
-        return DBUS_PRINTER_STOPPED;
+        return QStringLiteral(DBUS_PRINTER_STOPPED);
     }
 
     // job signals
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::jobCompleted)) {
-        return DBUS_JOB_COMPLETED;
+        return QStringLiteral(DBUS_JOB_COMPLETED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::jobConfigChanged)) {
-        return DBUS_JOB_CONFIG_CHANGED;
+        return QStringLiteral(DBUS_JOB_CONFIG_CHANGED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::jobCreated)) {
-        return DBUS_JOB_CREATED;
+        return QStringLiteral(DBUS_JOB_CREATED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::jobProgress)) {
-        return DBUS_JOB_PROGRESS;
+        return QStringLiteral(DBUS_JOB_PROGRESS);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::jobState)) {
-        return DBUS_JOB_STATE_CHANGED;
+        return QStringLiteral(DBUS_JOB_STATE_CHANGED);
     }
     if (signal == QMetaMethod::fromSignal(&KCupsConnection::jobStopped)) {
-        return DBUS_JOB_STOPPED;
+        return QStringLiteral(DBUS_JOB_STOPPED);
     }
 
     // No registered event signal matched
@@ -568,16 +567,16 @@ void KCupsConnection::renewDBusSubscription()
 
 void KCupsConnection::cancelDBusSubscription()
 {
-    KIppRequest request(IPP_CANCEL_SUBSCRIPTION, "/");
+    KIppRequest request(IPP_CANCEL_SUBSCRIPTION, QLatin1String("/"));
     request.addString(IPP_TAG_OPERATION, IPP_TAG_URI,
-                      KCUPS_PRINTER_URI, "/");
+                      KCUPS_PRINTER_URI, QLatin1String("/"));
     request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER,
                        KCUPS_NOTIFY_SUBSCRIPTION_ID, m_subscriptionId);
 
     do {
         // Do the request
         ippDelete(request.sendIppRequest());
-    } while (retry(request.resource().toUtf8(), request.operation()));
+    } while (retry(qUtf8Printable(request.resource()), request.operation()));
 
     // Reset the subscription id
     m_subscriptionId = -1;
@@ -870,7 +869,7 @@ const char * password_cb(const char *prompt, http_t *http, const char *method, c
         return NULL;
     }
 
-    KCupsPasswordDialog *passwordDialog = static_cast<KCupsPasswordDialog *>(user_data);
+    auto passwordDialog = static_cast<KCupsPasswordDialog *>(user_data);
     bool wrongPassword = password_retries > 1;
 
     // This will block this thread until exec is not finished
@@ -885,8 +884,8 @@ const char * password_cb(const char *prompt, http_t *http, const char *method, c
     // The password dialog has just returned check the result
     // method that returns QDialog enums
     if (passwordDialog->accepted()) {
-        cupsSetUser(passwordDialog->username().toUtf8());
-        return passwordDialog->password().toUtf8();
+        cupsSetUser(qUtf8Printable(passwordDialog->username()));
+        return qUtf8Printable(passwordDialog->password());
     } else {
         // the dialog was canceled
         password_retries = -1;
@@ -894,3 +893,5 @@ const char * password_cb(const char *prompt, http_t *http, const char *method, c
         return NULL;
     }
 }
+
+#include "moc_KCupsConnection.cpp"
