@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,17 +26,14 @@
 #include "KCupsPrinter.h"
 
 #include <KLocalizedString>
-#include <QStringBuilder>
 
 #include <cups/adminutil.h>
 #include <cups/ppd.h>
 
-#define CUPS_DATADIR    "/usr/share/cups"
+#define CUPS_DATADIR    QLatin1String("/usr/share/cups")
 
 KCupsRequest::KCupsRequest(KCupsConnection *connection) :
-    m_connection(connection),
-    m_finished(true),
-    m_error(IPP_OK)
+    m_connection(connection)
 {
     // If no connection was specified use default one
     if (m_connection == 0) {
@@ -61,7 +58,7 @@ QString KCupsRequest::serverError() const
 void KCupsRequest::getPPDS(const QString &make)
 {
     if (m_connection->readyToStart()) {
-        KIppRequest request(CUPS_GET_PPDS, "/");
+        KIppRequest request(CUPS_GET_PPDS, QLatin1String("/"));
         if (!make.isEmpty()) {
             request.addString(IPP_TAG_PRINTER, IPP_TAG_TEXT, KCUPS_PPD_MAKE_AND_MODEL, make);
         }
@@ -86,7 +83,7 @@ static void choose_device_cb(const char *device_class,           /* I - Class */
     /*
      * Add the device to the array...
      */
-    KCupsRequest *request = static_cast<KCupsRequest*>(user_data);
+    auto request = static_cast<KCupsRequest*>(user_data);
     QMetaObject::invokeMethod(request,
                               "device",
                               Qt::QueuedConnection,
@@ -111,14 +108,14 @@ void KCupsRequest::getDevices(int timeout, QStringList includeSchemes, QStringLi
             if (includeSchemes.isEmpty()) {
                 include = CUPS_INCLUDE_ALL;
             } else {
-                include = includeSchemes.join(QLatin1String(",")).toUtf8();
+                include = qUtf8Printable(includeSchemes.join(QLatin1String(",")));
             }
 
             const char *exclude;
             if (excludeSchemes.isEmpty()) {
                 exclude = CUPS_EXCLUDE_NONE;
             } else {
-                exclude = excludeSchemes.join(QLatin1String(",")).toUtf8();
+                exclude = qUtf8Printable(excludeSchemes.join(QLatin1String(",")));
             }
 
             // Scan for devices for "timeout" seconds
@@ -143,7 +140,7 @@ void KCupsRequest::getDevices(int timeout, QStringList includeSchemes, QStringLi
 void KCupsRequest::getPrinters(QStringList attributes, int mask)
 {
     if (m_connection->readyToStart()) {
-        KIppRequest request(CUPS_GET_PRINTERS, "/");
+        KIppRequest request(CUPS_GET_PRINTERS, QLatin1String("/"));
         request.addInteger(IPP_TAG_OPERATION, IPP_TAG_ENUM, KCUPS_PRINTER_TYPE, CUPS_PRINTER_LOCAL);
         if (!attributes.isEmpty()) {
             request.addStringList(IPP_TAG_OPERATION, IPP_TAG_KEYWORD, KCUPS_REQUESTED_ATTRIBUTES, attributes);
@@ -152,10 +149,9 @@ void KCupsRequest::getPrinters(QStringList attributes, int mask)
             request.addInteger(IPP_TAG_OPERATION, IPP_TAG_ENUM, KCUPS_PRINTER_TYPE_MASK, mask);
         }
 
-        ReturnArguments ret;
-        ret = m_connection->request(request, IPP_TAG_PRINTER);
+        const ReturnArguments ret = m_connection->request(request, IPP_TAG_PRINTER);
 
-        foreach (const QVariantHash &arguments, ret) {
+        for (const QVariantHash &arguments : ret) {
             m_printers << KCupsPrinter(arguments);
         }
 
@@ -169,16 +165,15 @@ void KCupsRequest::getPrinters(QStringList attributes, int mask)
 void KCupsRequest::getPrinterAttributes(const QString &printerName, bool isClass, QStringList attributes)
 {
     if (m_connection->readyToStart()) {
-        KIppRequest request(IPP_GET_PRINTER_ATTRIBUTES, "/");
+        KIppRequest request(IPP_GET_PRINTER_ATTRIBUTES, QLatin1String("/"));
 
         request.addPrinterUri(printerName, isClass);
-        request.addInteger(IPP_TAG_OPERATION, IPP_TAG_ENUM, KCUPS_PRINTER_TYPE, CUPS_PRINTER_LOCAL);
-        request.addStringList(IPP_TAG_OPERATION, IPP_TAG_KEYWORD, KCUPS_REQUESTED_ATTRIBUTES, attributes);
+        request.addInteger(IPP_TAG_OPERATION, IPP_TAG_ENUM, QLatin1String(KCUPS_PRINTER_TYPE), CUPS_PRINTER_LOCAL);
+        request.addStringList(IPP_TAG_OPERATION, IPP_TAG_KEYWORD, QLatin1String(KCUPS_REQUESTED_ATTRIBUTES), attributes);
 
-        ReturnArguments ret;
-        ret = m_connection->request(request, IPP_TAG_PRINTER);
+        const ReturnArguments ret = m_connection->request(request, IPP_TAG_PRINTER);
 
-        foreach (const QVariantHash &arguments, ret) {
+        for (const QVariantHash &arguments : ret) {
             // Inject the printer name back to the arguments hash
             QVariantHash args = arguments;
             args[KCUPS_PRINTER_NAME] = printerName;
@@ -195,7 +190,7 @@ void KCupsRequest::getPrinterAttributes(const QString &printerName, bool isClass
 void KCupsRequest::getJobs(const QString &printerName, bool myJobs, int whichJobs, QStringList attributes)
 {
     if (m_connection->readyToStart()) {
-        KIppRequest request(IPP_GET_JOBS, "/");
+        KIppRequest request(IPP_GET_JOBS, QLatin1String("/"));
 
         // printer-uri makes the Name of the Job and owner came blank lol
         request.addPrinterUri(printerName, false);
@@ -205,15 +200,14 @@ void KCupsRequest::getJobs(const QString &printerName, bool myJobs, int whichJob
         request.addInteger(IPP_TAG_OPERATION, IPP_TAG_ENUM, KCUPS_MY_JOBS, myJobs);
 
         if (whichJobs == CUPS_WHICHJOBS_COMPLETED) {
-            request.addString(IPP_TAG_OPERATION, IPP_TAG_KEYWORD, KCUPS_WHICH_JOBS, "completed");
+            request.addString(IPP_TAG_OPERATION, IPP_TAG_KEYWORD, KCUPS_WHICH_JOBS, QLatin1String("completed"));
         } else if (whichJobs == CUPS_WHICHJOBS_ALL) {
-            request.addString(IPP_TAG_OPERATION, IPP_TAG_KEYWORD, KCUPS_WHICH_JOBS, "all");
+            request.addString(IPP_TAG_OPERATION, IPP_TAG_KEYWORD, KCUPS_WHICH_JOBS, QLatin1String("all"));
         }
 
-        ReturnArguments ret;
-        ret = m_connection->request(request, IPP_TAG_JOB);
+        const ReturnArguments ret = m_connection->request(request, IPP_TAG_JOB);
 
-        foreach (const QVariantHash &arguments, ret) {
+        for (const QVariantHash &arguments : ret) {
             m_jobs << KCupsJob(arguments);
         }
 
@@ -227,7 +221,7 @@ void KCupsRequest::getJobs(const QString &printerName, bool myJobs, int whichJob
 void KCupsRequest::getJobAttributes(int jobId, const QString &printerUri, QStringList attributes)
 {
     if (m_connection->readyToStart()) {
-        KIppRequest request(IPP_GET_JOB_ATTRIBUTES, "/");
+        KIppRequest request(IPP_GET_JOB_ATTRIBUTES, QLatin1String("/"));
 
         request.addString(IPP_TAG_OPERATION, IPP_TAG_URI, KCUPS_PRINTER_URI, printerUri);
         request.addInteger(IPP_TAG_OPERATION, IPP_TAG_ENUM, KCUPS_PRINTER_TYPE, CUPS_PRINTER_LOCAL);
@@ -235,10 +229,9 @@ void KCupsRequest::getJobAttributes(int jobId, const QString &printerUri, QStrin
 
         request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER, KCUPS_JOB_ID, jobId);
 
-        ReturnArguments ret;
-        ret = m_connection->request(request, IPP_TAG_PRINTER);
+        const ReturnArguments ret = m_connection->request(request, IPP_TAG_PRINTER);
 
-        foreach (const QVariantHash &arguments, ret) {
+        for (const QVariantHash &arguments : ret) {
             m_jobs << KCupsJob(arguments);
         }
 
@@ -282,9 +275,9 @@ void KCupsRequest::getPrinterPPD(const QString &printerName)
     if (m_connection->readyToStart()) {
         do {
             const char  *filename;
-            filename = cupsGetPPD2(CUPS_HTTP_DEFAULT, printerName.toUtf8());
+            filename = cupsGetPPD2(CUPS_HTTP_DEFAULT, qUtf8Printable(printerName));
             qCDebug(LIBKCUPS) << filename;
-            m_ppdFile = filename;
+            m_ppdFile = QString::fromUtf8(filename);
             qCDebug(LIBKCUPS) << m_ppdFile;
         } while (m_connection->retry("/", CUPS_GET_PPD));
         setError(httpGetStatus(CUPS_HTTP_DEFAULT), cupsLastError(), QString::fromUtf8(cupsLastErrorString()));
@@ -304,8 +297,8 @@ void KCupsRequest::setServerSettings(const KCupsServer &server)
 
             QVariantHash::const_iterator i = args.constBegin();
             while (i != args.constEnd()) {
-                num_settings = cupsAddOption(i.key().toUtf8(),
-                                             i.value().toString().toUtf8(),
+                num_settings = cupsAddOption(qUtf8Printable(i.key()),
+                                             qUtf8Printable(i.value().toString()),
                                              num_settings,
                                              &settings);
                 ++i;
@@ -323,7 +316,7 @@ void KCupsRequest::setServerSettings(const KCupsServer &server)
 
 void KCupsRequest::addOrModifyPrinter(const QString &printerName, const QVariantHash &attributes, const QString &filename)
 {
-    KIppRequest request(CUPS_ADD_MODIFY_PRINTER, "/admin/", filename);
+    KIppRequest request(CUPS_ADD_MODIFY_PRINTER, QLatin1String("/admin/"), filename);
     request.addPrinterUri(printerName);
     request.addVariantValues(attributes);
 
@@ -332,7 +325,7 @@ void KCupsRequest::addOrModifyPrinter(const QString &printerName, const QVariant
 
 void KCupsRequest::addOrModifyClass(const QString &printerName, const QVariantHash &attributes)
 {
-    KIppRequest request(CUPS_ADD_MODIFY_CLASS, "/admin/");
+    KIppRequest request(CUPS_ADD_MODIFY_CLASS, QLatin1String("/admin/"));
     request.addPrinterUri(printerName, true);
     request.addVariantValues(attributes);
 
@@ -341,7 +334,7 @@ void KCupsRequest::addOrModifyClass(const QString &printerName, const QVariantHa
 
 void KCupsRequest::setShared(const QString &printerName, bool isClass, bool shared)
 {
-    KIppRequest request(isClass ? CUPS_ADD_MODIFY_CLASS : CUPS_ADD_MODIFY_PRINTER, "/admin/");
+    KIppRequest request(isClass ? CUPS_ADD_MODIFY_CLASS : CUPS_ADD_MODIFY_PRINTER, QLatin1String("/admin/"));
     request.addPrinterUri(printerName, isClass);
     request.addBoolean(IPP_TAG_OPERATION, KCUPS_PRINTER_IS_SHARED, shared);
 
@@ -350,7 +343,7 @@ void KCupsRequest::setShared(const QString &printerName, bool isClass, bool shar
 
 void KCupsRequest::pausePrinter(const QString &printerName)
 {
-    KIppRequest request(IPP_PAUSE_PRINTER, "/admin/");
+    KIppRequest request(IPP_PAUSE_PRINTER, QLatin1String("/admin/"));
     request.addPrinterUri(printerName);
 
     process(request);
@@ -358,7 +351,7 @@ void KCupsRequest::pausePrinter(const QString &printerName)
 
 void KCupsRequest::resumePrinter(const QString &printerName)
 {
-    KIppRequest request(IPP_RESUME_PRINTER, "/admin/");
+    KIppRequest request(IPP_RESUME_PRINTER, QLatin1String("/admin/"));
     request.addPrinterUri(printerName);
 
     process(request);
@@ -366,7 +359,7 @@ void KCupsRequest::resumePrinter(const QString &printerName)
 
 void KCupsRequest::rejectJobs(const QString &printerName)
 {
-    KIppRequest request(CUPS_REJECT_JOBS, "/admin/");
+    KIppRequest request(CUPS_REJECT_JOBS, QLatin1String("/admin/"));
     request.addPrinterUri(printerName);
 
     process(request);
@@ -374,7 +367,7 @@ void KCupsRequest::rejectJobs(const QString &printerName)
 
 void KCupsRequest::acceptJobs(const QString &printerName)
 {
-    KIppRequest request(CUPS_ACCEPT_JOBS, "/admin/");
+    KIppRequest request(CUPS_ACCEPT_JOBS, QLatin1String("/admin/"));
     request.addPrinterUri(printerName);
 
     process(request);
@@ -382,7 +375,7 @@ void KCupsRequest::acceptJobs(const QString &printerName)
 
 void KCupsRequest::setDefaultPrinter(const QString &printerName)
 {
-    KIppRequest request(CUPS_SET_DEFAULT, "/admin/");
+    KIppRequest request(CUPS_SET_DEFAULT, QLatin1String("/admin/"));
     request.addPrinterUri(printerName);
 
     process(request);
@@ -390,7 +383,7 @@ void KCupsRequest::setDefaultPrinter(const QString &printerName)
 
 void KCupsRequest::deletePrinter(const QString &printerName)
 {
-    KIppRequest request(CUPS_DELETE_PRINTER, "/admin/");
+    KIppRequest request(CUPS_DELETE_PRINTER, QLatin1String("/admin/"));
     request.addPrinterUri(printerName);
 
     process(request);
@@ -405,7 +398,7 @@ void KCupsRequest::printTestPage(const QString &printerName, bool isClass)
     /*
      * Locate the test page file...
      */
-    datadir = qgetenv("CUPS_DATADIR");
+    datadir = QString::fromUtf8(qgetenv("CUPS_DATADIR"));
     if (datadir.isEmpty()) {
         datadir = CUPS_DATADIR;
     }
@@ -415,12 +408,12 @@ void KCupsRequest::printTestPage(const QString &printerName, bool isClass)
      * Point to the printer/class...
      */
     if (isClass) {
-        resource = QLatin1String("/classes/") % printerName;
+        resource = QLatin1String("/classes/") + printerName;
     } else {
-        resource = QLatin1String("/printers/") % printerName;
+        resource = QLatin1String("/printers/") + printerName;
     }
 
-    KIppRequest request(IPP_PRINT_JOB, resource.toUtf8(), filename);
+    KIppRequest request(IPP_PRINT_JOB, resource, filename);
     request.addPrinterUri(printerName);
     request.addString(IPP_TAG_OPERATION, IPP_TAG_NAME, KCUPS_JOB_NAME, i18n("Test Page"));
 
@@ -439,7 +432,7 @@ void KCupsRequest::printCommand(const QString &printerName, const QString &comma
             /*
              * Create the CUPS command file...
              */
-            snprintf(command_file, sizeof(command_file), "#CUPS-COMMAND\n%s\n", command.toUtf8().data());
+            snprintf(command_file, sizeof(command_file), "#CUPS-COMMAND\n%s\n", command.toUtf8().constData());
 
             /*
              * Send the command file job...
@@ -448,8 +441,8 @@ void KCupsRequest::printCommand(const QString &printerName, const QString &comma
             hold_option.value = const_cast<char*>("no-hold");
 
             if ((job_id = cupsCreateJob(CUPS_HTTP_DEFAULT,
-                                        printerName.toUtf8(),
-                                        title.toUtf8(),
+                                        qUtf8Printable(printerName),
+                                        qUtf8Printable(title),
                                         1,
                                         &hold_option)) < 1) {
                 qWarning() << "Unable to send command to printer driver!";
@@ -460,7 +453,7 @@ void KCupsRequest::printCommand(const QString &printerName, const QString &comma
             }
 
             status = cupsStartDocument(CUPS_HTTP_DEFAULT,
-                                       printerName.toUtf8(),
+                                       qUtf8Printable(printerName),
                                        job_id,
                                        NULL,
                                        CUPS_FORMAT_COMMAND,
@@ -471,14 +464,14 @@ void KCupsRequest::printCommand(const QString &printerName, const QString &comma
             }
 
             if (status == HTTP_CONTINUE) {
-                cupsFinishDocument(CUPS_HTTP_DEFAULT, printerName.toUtf8());
+                cupsFinishDocument(CUPS_HTTP_DEFAULT, qUtf8Printable(printerName));
             }
 
             setError(httpGetStatus(CUPS_HTTP_DEFAULT), cupsLastError(), QString::fromUtf8(cupsLastErrorString()));
             if (httpGetStatus(CUPS_HTTP_DEFAULT), cupsLastError() >= IPP_REDIRECTION_OTHER_SITE) {
                 qWarning() << "Unable to send command to printer driver!";
 
-                cupsCancelJob(printerName.toUtf8(), job_id);
+                cupsCancelJob(qUtf8Printable(printerName), job_id);
                 setFinished();
                 return; // Return to avoid a new try
             }
@@ -492,7 +485,7 @@ void KCupsRequest::printCommand(const QString &printerName, const QString &comma
 
 void KCupsRequest::cancelJob(const QString &printerName, int jobId)
 {
-    KIppRequest request(IPP_CANCEL_JOB, "/jobs/");
+    KIppRequest request(IPP_CANCEL_JOB, QLatin1String("/jobs/"));
     request.addPrinterUri(printerName);
     request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER, KCUPS_JOB_ID, jobId);
 
@@ -501,7 +494,7 @@ void KCupsRequest::cancelJob(const QString &printerName, int jobId)
 
 void KCupsRequest::holdJob(const QString &printerName, int jobId)
 {
-    KIppRequest request(IPP_HOLD_JOB, "/jobs/");
+    KIppRequest request(IPP_HOLD_JOB, QLatin1String("/jobs/"));
     request.addPrinterUri(printerName);
     request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER, KCUPS_JOB_ID, jobId);
 
@@ -510,7 +503,7 @@ void KCupsRequest::holdJob(const QString &printerName, int jobId)
 
 void KCupsRequest::releaseJob(const QString &printerName, int jobId)
 {
-    KIppRequest request(IPP_RELEASE_JOB, "/jobs/");
+    KIppRequest request(IPP_RELEASE_JOB, QLatin1String("/jobs/"));
     request.addPrinterUri(printerName);
     request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER, KCUPS_JOB_ID, jobId);
 
@@ -519,7 +512,7 @@ void KCupsRequest::releaseJob(const QString &printerName, int jobId)
 
 void KCupsRequest::restartJob(const QString &printerName, int jobId)
 {
-    KIppRequest request(IPP_RESTART_JOB, "/jobs/");
+    KIppRequest request(IPP_RESTART_JOB, QLatin1String("/jobs/"));
     request.addPrinterUri(printerName);
     request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER, KCUPS_JOB_ID, jobId);
 
@@ -534,7 +527,7 @@ void KCupsRequest::moveJob(const QString &fromPrinterName, int jobId, const QStr
         return;
     }
 
-    KIppRequest request(CUPS_MOVE_JOB, "/jobs/");
+    KIppRequest request(CUPS_MOVE_JOB, QLatin1String("/jobs/"));
     request.addPrinterUri(fromPrinterName);
     request.addInteger(IPP_TAG_OPERATION, IPP_TAG_INTEGER, KCUPS_JOB_ID, jobId);
 
@@ -578,7 +571,7 @@ void KCupsRequest::invokeMethod(const char *method,
                                             QGenericArgument(arg7.typeName(), arg7.data()),
                                             QGenericArgument(arg8.typeName(), arg8.data()));
     if (m_finished) {
-        setError(HTTP_ERROR, IPP_BAD_REQUEST, i18n("Failed to invoke method: %1", method));
+        setError(HTTP_ERROR, IPP_BAD_REQUEST, i18n("Failed to invoke method: %1", QLatin1String(method)));
         setFinished();
     }
 }
@@ -665,8 +658,12 @@ void KCupsRequest::setFinished(bool delayed)
 {
     m_finished = true;
     if (delayed) {
-        QTimer::singleShot(0, this, SIGNAL(finished()));
+        QTimer::singleShot(0, this, [this] () {
+            emit finished(this);
+        });
     } else {
-        emit finished();
+        emit finished(this);
     }
 }
+
+#include "moc_KCupsRequest.cpp"
