@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
- *   dantti12@gmail.com                                                    *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti <dantti12@gmail.com>      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,8 +21,6 @@
 
 #include "Debug.h"
 
-#include <QStringBuilder>
-
 #include <KLocalizedString>
 
 PPDModel::PPDModel(QObject *parent) :
@@ -36,10 +33,10 @@ void PPDModel::setPPDs(const QList<QVariantHash> &ppds, const DriverMatchList &d
     clear();
 
     QStandardItem *recommended = 0;
-    foreach (const DriverMatch &driver, driverMatch) {
+    for (const DriverMatch &driver : driverMatch) {
         // Find the matched PPD on the PPDs list
-        foreach (const QVariantHash &ppd, ppds) {
-            if (ppd["ppd-name"].toString() == driver.ppd) {
+        for (const QVariantHash &ppd : ppds) {
+            if (ppd[QLatin1String("ppd-name")].toString() == driver.ppd) {
                 // Create the PPD
                 QStandardItem *ppdItem = createPPDItem(ppd, true);
 
@@ -55,9 +52,9 @@ void PPDModel::setPPDs(const QList<QVariantHash> &ppds, const DriverMatchList &d
         }
     }
 
-    foreach (const QVariantHash &ppd, ppds) {
+    for (const QVariantHash &ppd : ppds) {
         // Find or create the PPD parent (printer Make)
-        QStandardItem *makeItem = findCreateMake(ppd["ppd-make"].toString());
+        QStandardItem *makeItem = findCreateMake(ppd[QLatin1String("ppd-make")].toString());
 
         // Create the PPD
         QStandardItem *ppdItem = createPPDItem(ppd, false);
@@ -74,7 +71,7 @@ QStandardItem* PPDModel::findCreateMake(const QString &make)
         }
     }
 
-    QStandardItem *makeItem = new QStandardItem(make);
+    auto makeItem = new QStandardItem(make);
     appendRow(makeItem);
     return makeItem;
 }
@@ -93,12 +90,12 @@ void PPDModel::clear()
 
 QStandardItem *PPDModel::createPPDItem(const QVariantHash &ppd, bool recommended)
 {
-    QStandardItem *ret = new QStandardItem;
+    auto ret = new QStandardItem;
 
-    QString make = ppd["ppd-make"].toString();
-    QString makeAndModel = ppd["ppd-make-and-model"].toString();
-    QString naturalLanguage = ppd["ppd-natural-language"].toString();
-    QString ppdName = ppd["ppd-name"].toString();
+    QString make = ppd[QLatin1String("ppd-make")].toString();
+    QString makeAndModel = ppd[QLatin1String("ppd-make-and-model")].toString();
+    QString naturalLanguage = ppd[QLatin1String("ppd-natural-language")].toString();
+    QString ppdName = ppd[QLatin1String("ppd-name")].toString();
 
     // Set this data before we change the makeAndModel
     ret->setData(ppdName, PPDName);
@@ -127,3 +124,5 @@ QStandardItem *PPDModel::createPPDItem(const QVariantHash &ppd, bool recommended
 
     return ret;
 }
+
+#include "moc_PPDModel.cpp"
