@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,6 +26,7 @@
 
 #include <KCupsPrinter.h>
 
+class KCupsRequest;
 class Q_DECL_EXPORT PrinterModel : public QStandardItemModel
 {
     Q_OBJECT
@@ -68,6 +69,8 @@ public:
     int count() const;
     bool serverUnavailable() const;
 
+    virtual QHash<int,QByteArray> roleNames() const override;
+
     Q_INVOKABLE void pausePrinter(const QString &printerName);
     Q_INVOKABLE void resumePrinter(const QString &printerName);
     Q_INVOKABLE void rejectJobs(const QString &printerName);
@@ -75,7 +78,7 @@ public:
 
 public slots:
     void update();
-    void getDestsFinished();
+    void getDestsFinished(KCupsRequest *request);
     void slotCountChanged();
 
 signals:
@@ -84,15 +87,15 @@ signals:
     void error(int lastError, const QString &errorTitle, const QString &errorMsg);
 
 private slots:
-    void insertUpdatePrinter(const QString &printerName);
+    void insertUpdatePrinterName(const QString &printerName);
     void insertUpdatePrinter(const QString &text,
                              const QString &printerUri,
                              const QString &printerName,
                              uint printerState,
                              const QString &printerStateReasons,
                              bool printerIsAcceptingJobs);
-    void insertUpdatePrinterFinished();
-    void printerRemoved(const QString &printerName);
+    void insertUpdatePrinterFinished(KCupsRequest *request);
+    void printerRemovedName(const QString &printerName);
     void printerRemoved(const QString &text, const QString &printerUri, const QString &printerName, uint printerState, const QString &printerStateReasons, bool printerIsAcceptingJobs);
     void printerStateChanged(const QString &text, const QString &printerUri, const QString &printerName, uint printerState, const QString &printerStateReasons, bool printerIsAcceptingJobs);
     void printerStopped(const QString &text, const QString &printerUri, const QString &printerName, uint printerState, const QString &printerStateReasons, bool printerIsAcceptingJobs);
@@ -103,8 +106,8 @@ private slots:
 
 private:
     WId m_parentId;
-    QStringList m_attributes;
-    bool m_unavailable;
+    QHash<int, QByteArray> m_roles;
+    bool m_unavailable = true;
 
     int destRow(const QString &destName);
     void insertDest(int pos, const KCupsPrinter &printer);
