@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,7 +30,6 @@
 #include "PrinterDescription.h"
 
 #include <KMessageBox>
-#include <KPluginFactory>
 #include <KAboutData>
 #include <KToolInvocation>
 #include <KIconLoader>
@@ -43,47 +42,42 @@
 
 #include <cups/cups.h>
 
-K_PLUGIN_FACTORY(PrintKCMFactory, registerPlugin<PrintKCM>();)
-
 PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
     KCModule(parent, args),
-    ui(new Ui::PrintKCM),
-    m_lastError(-1), // Force the error to run on the first time
-    m_serverRequest(0)
+    ui(new Ui::PrintKCM)
 {
-    KAboutData *aboutData;
-    aboutData = new KAboutData("kcm_print",
-                               i18n("Print settings"),
-                               PM_VERSION,
-                               i18n("Print settings"),
-                               KAboutLicense::GPL,
-                               i18n("(C) 2010-2013 Daniel Nicoletti"));
-    aboutData->addAuthor(QStringLiteral("Daniel Nicoletti"), QString(), "dantti12@gmail.com");
+    auto aboutData = new KAboutData(QLatin1String("kcm_print"),
+                                    i18n("Print settings"),
+                                    QLatin1String(PM_VERSION),
+                                    i18n("Print settings"),
+                                    KAboutLicense::GPL,
+                                    i18n("(C) 2010-2018 Daniel Nicoletti"));
+    aboutData->addAuthor(QStringLiteral("Daniel Nicoletti"), QString(), QLatin1String("dantti12@gmail.com"));
     aboutData->addAuthor(QStringLiteral("Jan Grulich"), i18n("Port to Qt 5 / Plasma 5"), QStringLiteral("jgrulich@redhat.com"));
     setAboutData(aboutData);
     setButtons(NoAdditionalButton);
 
     ui->setupUi(this);
 
-    connect(ui->printerDesc, SIGNAL(updateNeeded()), SLOT(update()));
+    connect(ui->printerDesc, &PrinterDescription::updateNeeded, this, &PrintKCM::update);
 
     // The printer list needs to increase in width according to the icon sizes
     // default dialog icon size is 32, this times 6 is 192 which is roughly the original width
     ui->printersTV->setMinimumWidth(IconSize(KIconLoader::Dialog) * 6);
 
-    QMenu *addMenu = new QMenu(this);
+    auto addMenu = new QMenu(this);
     addMenu->addAction(i18nc("@action:intoolbar","Add a Printer Class"),
-                       this, SLOT(addClass()));
-    ui->addTB->setIcon(QIcon::fromTheme("list-add"));
+                       this, &PrintKCM::addClass);
+    ui->addTB->setIcon(QIcon::fromTheme(QLatin1String("list-add")));
     ui->addTB->setToolTip(i18n("Add a new printer or a printer class"));
     ui->addTB->setMenu(addMenu);
 
-    ui->removeTB->setIcon(QIcon::fromTheme("list-remove"));
+    ui->removeTB->setIcon(QIcon::fromTheme(QLatin1String("list-remove")));
     ui->removeTB->setToolTip(i18n("Remove Printer"));
 
-    QMenu *systemMenu = new QMenu(this);
-    connect(systemMenu, SIGNAL(aboutToShow()), this, SLOT(getServerSettings()));
-    connect(systemMenu, SIGNAL(triggered(QAction*)), this, SLOT(systemPreferencesTriggered()));
+    auto systemMenu = new QMenu(this);
+    connect(systemMenu, &QMenu::aboutToShow, this, &PrintKCM::getServerSettings);
+    connect(systemMenu, &QMenu::triggered, this, &PrintKCM::systemPreferencesTriggered);
 #if CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR < 6
     m_showSharedPrinters = systemMenu->addAction(i18nc("@action:intoolbar","Show printers shared by other systems"));
     m_showSharedPrinters->setCheckable(true);
@@ -94,47 +88,42 @@ PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
     m_allowPrintringFromInternet = systemMenu->addAction(i18nc("@action:intoolbar","Allow printing from the Internet"));
     m_allowPrintringFromInternet->setCheckable(true);
     m_allowPrintringFromInternet->setEnabled(false);
-    connect(m_shareConnectedPrinters, SIGNAL(toggled(bool)), m_allowPrintringFromInternet, SLOT(setEnabled(bool)));
-    connect(m_shareConnectedPrinters, SIGNAL(toggled(bool)), ui->printerDesc, SLOT(enableShareCheckBox(bool)));
+    connect(m_shareConnectedPrinters, &QAction::toggled, m_allowPrintringFromInternet, &QAction::setEnabled);
+    connect(m_shareConnectedPrinters, &QAction::toggled, ui->printerDesc, &PrinterDescription::enableShareCheckBox);
     systemMenu->addSeparator();
     m_allowRemoteAdmin = systemMenu->addAction(i18nc("@action:intoolbar","Allow remote administration"));
     m_allowRemoteAdmin->setCheckable(true);
     m_allowUsersCancelAnyJob = systemMenu->addAction(i18nc("@action:intoolbar","Allow users to cancel any job (not just their own)"));
     m_allowUsersCancelAnyJob->setCheckable(true);
 
-    ui->systemPreferencesTB->setIcon(QIcon::fromTheme("configure"));
+    ui->systemPreferencesTB->setIcon(QIcon::fromTheme(QLatin1String("configure")));
     ui->systemPreferencesTB->setToolTip(i18n("Configure the global preferences"));
     ui->systemPreferencesTB->setMenu(systemMenu);
 
     m_model = new PrinterModel(this);
-    PrinterSortFilterModel *sortModel = new PrinterSortFilterModel(this);
+    auto sortModel = new PrinterSortFilterModel(this);
     sortModel->setSourceModel(m_model);
     ui->printersTV->setModel(sortModel);
     ui->printersTV->setItemDelegate(new NoSelectionRectDelegate(this));
     ui->printersTV->setItemDelegate(new PrinterDelegate(this));
-    connect(ui->printersTV->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(update()));
-    connect(sortModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(update()));
-    connect(sortModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            this, SLOT(update()));
-    connect(m_model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SLOT(update()));
-    connect(m_model, SIGNAL(error(int,QString,QString)),
-            this, SLOT(error(int,QString,QString)));
+    connect(ui->printersTV->selectionModel(), &QItemSelectionModel::selectionChanged, this, &PrintKCM::update);
+    connect(sortModel, &PrinterSortFilterModel::rowsInserted, this, &PrintKCM::update);
+    connect(sortModel, &PrinterSortFilterModel::rowsRemoved, this, &PrintKCM::update);
+    connect(m_model, &PrinterModel::dataChanged, this, &PrintKCM::update);
+    connect(m_model, &PrinterModel::error, this, &PrintKCM::error);
 
-    ui->addPrinterBtn->setIcon(QIcon::fromTheme("list-add"));
-    connect(ui->addPrinterBtn, SIGNAL(clicked()), this, SLOT(on_addTB_clicked()));
+    ui->addPrinterBtn->setIcon(QIcon::fromTheme(QLatin1String("list-add")));
+    connect(ui->addPrinterBtn, &QPushButton::clicked, this, &PrintKCM::on_addTB_clicked);
 
     // Force the model update AFTER we setup the error signal
     m_model->update();
 
     // Make sure we update our server settings if the user change it on
     // another interface
-    connect(KCupsConnection::global(), SIGNAL(serverAudit(QString)), this, SLOT(getServerSettings()));
-    connect(KCupsConnection::global(), SIGNAL(serverRestarted(QString)), this, SLOT(getServerSettings()));
-    connect(KCupsConnection::global(), SIGNAL(serverStarted(QString)), this, SLOT(getServerSettings()));
-    connect(KCupsConnection::global(), SIGNAL(serverStopped(QString)), this, SLOT(getServerSettings()));
+    connect(KCupsConnection::global(), &KCupsConnection::serverAudit, this, &PrintKCM::getServerSettings);
+    connect(KCupsConnection::global(), &KCupsConnection::serverStarted, this, &PrintKCM::getServerSettings);
+    connect(KCupsConnection::global(), &KCupsConnection::serverStopped, this, &PrintKCM::getServerSettings);
+    connect(KCupsConnection::global(), &KCupsConnection::serverRestarted, this, &PrintKCM::getServerSettings);
 
     // We need to know the server settings so we disable the
     // share printer checkbox if sharing is disabled on the server
@@ -152,13 +141,13 @@ void PrintKCM::error(int lastError, const QString &errorTitle, const QString &er
         // The user has no printer
         // allow him to add a new one
         if (lastError == IPP_NOT_FOUND) {
-            showInfo(QIcon::fromTheme("dialog-information"),
+            showInfo(QIcon::fromTheme(QLatin1String("dialog-information")),
                      i18n("No printers have been configured or discovered"),
                      QString(),
                      true,
                      true);
         } else {
-            showInfo(QIcon::fromTheme("printer"),
+            showInfo(QIcon::fromTheme(QLatin1String("printer")),
                      QStringLiteral("<strong>%1</strong>").arg(errorTitle),
                      errorMsg,
                      false,
@@ -252,7 +241,7 @@ void PrintKCM::update()
 
         if (m_lastError == IPP_OK) {
             // the model is empty and no problem happened
-            showInfo(QIcon::fromTheme("dialog-information"),
+            showInfo(QIcon::fromTheme(QLatin1String("dialog-information")),
                      i18n("No printers have been configured or discovered"),
                      QString(),
                      true,
@@ -263,16 +252,14 @@ void PrintKCM::update()
 
 void PrintKCM::on_addTB_clicked()
 {
-    QStringList args;
-    args << "--add-printer";
-    KToolInvocation::kdeinitExec(QLatin1String("kde-add-printer"), args);
+    KToolInvocation::kdeinitExec(QLatin1String("kde-add-printer"),
+    { QLatin1String("--add-printer") });
 }
 
 void PrintKCM::addClass()
 {
-    QStringList args;
-    args << "--add-class";
-    KToolInvocation::kdeinitExec(QLatin1String("kde-add-printer"), args);
+    KToolInvocation::kdeinitExec(QLatin1String("kde-add-printer"),
+    { QLatin1String("--add-class") });
 }
 
 void PrintKCM::on_removeTB_clicked()
@@ -309,19 +296,16 @@ void PrintKCM::on_removeTB_clicked()
 void PrintKCM::getServerSettings()
 {
     if (!m_serverRequest) {
-        QMenu *systemMenu = qobject_cast<QMenu*>(sender());
+        auto systemMenu = qobject_cast<QMenu*>(sender());
         m_serverRequest = new KCupsRequest;
         m_serverRequest->setProperty("interactive", static_cast<bool>(systemMenu));
-        connect(m_serverRequest, SIGNAL(finished()),
-                this, SLOT(getServerSettingsFinished()));
+        connect(m_serverRequest, &KCupsRequest::finished, this, &PrintKCM::getServerSettingsFinished);
         m_serverRequest->getServerSettings();
     }
 }
 
-void PrintKCM::getServerSettingsFinished()
+void PrintKCM::getServerSettingsFinished(KCupsRequest *request)
 {
-    KCupsRequest *request = qobject_cast<KCupsRequest *>(sender());
-
     // When we don't have any destinations error is set to IPP_NOT_FOUND
     // we can safely ignore the error since it DOES bring the server settings
     bool error = request->hasError() && request->error() != IPP_NOT_FOUND;
@@ -357,15 +341,14 @@ void PrintKCM::getServerSettingsFinished()
     m_serverRequest = 0;
 }
 
-void PrintKCM::updateServerFinished()
+void PrintKCM::updateServerFinished(KCupsRequest *request)
 {
-    KCupsRequest *request = qobject_cast<KCupsRequest *>(sender());
     if (request->hasError()) {
         if (request->error() == IPP_SERVICE_UNAVAILABLE ||
                 request->error() == IPP_INTERNAL_ERROR ||
                 request->error() == IPP_AUTHENTICATION_CANCELED) {
             // Server is restarting, or auth was canceled, update the settings in one second
-            QTimer::singleShot(1000, this, SLOT(update()));
+            QTimer::singleShot(1000, this, &PrintKCM::update);
         } else {
             KMessageBox::detailedSorry(this,
                                        i18nc("@info", "Failed to configure server settings"),
@@ -389,9 +372,9 @@ void PrintKCM::systemPreferencesTriggered()
     server.setAllowPrintingFromInternet(m_allowPrintringFromInternet->isChecked());
     server.setAllowRemoteAdmin(m_allowRemoteAdmin->isChecked());
     server.setAllowUserCancelAnyJobs(m_allowUsersCancelAnyJob->isChecked());
-    KCupsRequest *request = new KCupsRequest;
-    connect(request, SIGNAL(finished()), this, SLOT(updateServerFinished()));
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, &PrintKCM::updateServerFinished);
     request->setServerSettings(server);
 }
 
-#include "PrintKCM.moc"
+#include "moc_PrintKCM.cpp"
