@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,22 +38,19 @@ Q_DECLARE_METATYPE(QList<int>)
 
 PrinterDescription::PrinterDescription(QWidget *parent) :
     QWidget(parent),
-    ui(new Ui::PrinterDescription),
-    m_isClass(false),
-    m_globalShared(false),
-    m_markerChangeTime(0)
+    ui(new Ui::PrinterDescription)
 {
     ui->setupUi(this);
     m_layoutEnd = ui->formLayout->count();
 
     // loads the standard key icon
-    m_printerIcon = KIconLoader::global()->loadIcon("printer",
+    m_printerIcon = KIconLoader::global()->loadIcon(QLatin1String("printer"),
                     KIconLoader::NoGroup,
                     PRINTER_ICON_SIZE, // a not so huge icon
                     KIconLoader::DefaultState);
     ui->iconL->setPixmap(m_printerIcon);
 
-    m_pauseIcon = KIconLoader::global()->loadIcon("media-playback-pause",
+    m_pauseIcon = KIconLoader::global()->loadIcon(QLatin1String("media-playback-pause"),
                   KIconLoader::NoGroup,
                   KIconLoader::SizeMedium,
                   KIconLoader::DefaultState,
@@ -61,7 +58,7 @@ PrinterDescription::PrinterDescription(QWidget *parent) :
                   0,
                   true);
 
-    QMenu *menu = new QMenu(ui->maintenancePB);
+    auto menu = new QMenu(ui->maintenancePB);
     menu->addAction(ui->actionPrintTestPage);
     menu->addAction(ui->actionPrintSelfTestPage);
     menu->addAction(ui->actionCleanPrintHeads);
@@ -80,32 +77,30 @@ PrinterDescription::~PrinterDescription()
 
 void PrinterDescription::on_openQueuePB_clicked()
 {
-    QStringList args;
-    args << m_destName;
-    KToolInvocation::kdeinitExec(QLatin1String("kde-print-queue"), args);
+    KToolInvocation::kdeinitExec(QLatin1String("kde-print-queue"), { m_destName });
 }
 
 void PrinterDescription::on_defaultCB_clicked()
 {
     ui->defaultCB->setDisabled(true);
-    KCupsRequest *request = new KCupsRequest;
-    connect(request, SIGNAL(finished()), this, SLOT(requestFinished()));
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, &PrinterDescription::requestFinished);
     request->setDefaultPrinter(m_destName);
 }
 
 void PrinterDescription::on_sharedCB_clicked()
 {
     ui->sharedCB->setDisabled(true);
-    KCupsRequest *request = new KCupsRequest;
-    connect(request, SIGNAL(finished()), this, SLOT(requestFinished()));
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, &PrinterDescription::requestFinished);
     request->setShared(m_destName, m_isClass, ui->sharedCB->isChecked());
 }
 
 void PrinterDescription::on_rejectPrintJobsCB_clicked()
 {
     ui->rejectPrintJobsCB->setDisabled(true);
-    KCupsRequest *request = new KCupsRequest;
-    connect(request, SIGNAL(finished()), this, SLOT(requestFinished()));
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, &PrinterDescription::requestFinished);
     if (ui->rejectPrintJobsCB->isChecked()) {
         request->rejectJobs(m_destName);
     } else {
@@ -186,8 +181,8 @@ void PrinterDescription::setCommands(const QStringList &commands)
     if (m_commands != commands) {
         m_commands = commands;
 
-        ui->actionCleanPrintHeads->setVisible(commands.contains("Clean"));
-        ui->actionPrintSelfTestPage->setVisible(commands.contains("PrintSelfTestPage"));
+        ui->actionCleanPrintHeads->setVisible(commands.contains(QLatin1String("Clean")));
+        ui->actionPrintSelfTestPage->setVisible(commands.contains(QLatin1String("PrintSelfTestPage")));
 
         // TODO if the printer supports ReportLevels
         // we should probably probe for them
@@ -202,31 +197,31 @@ void PrinterDescription::setMarkers(const QVariantHash &data)
         ui->formLayout->takeAt(ui->formLayout->count() - 1)->widget()->deleteLater();
     }
 
-    int size = data["marker-names"].toStringList().size();
-    if (size != data["marker-levels"].value<QList<int> >().size() ||
-            size != data["marker-colors"].toStringList().size() ||
-            size != data["marker-types"].toStringList().size()) {
+    int size = data[KCUPS_MARKER_NAMES].toStringList().size();
+    if (size != data[KCUPS_MARKER_LEVELS].value<QList<int> >().size() ||
+            size != data[KCUPS_MARKER_COLORS].toStringList().size() ||
+            size != data[KCUPS_MARKER_TYPES].toStringList().size()) {
         return;
     }
 
     // Create a colored progress bar for each marker
     for (int i = 0; i < size; i++) {
-        if (data["marker-types"].toStringList().at(i) == QLatin1String("unknown")) {
+        if (data[KCUPS_MARKER_TYPES].toStringList().at(i) == QLatin1String("unknown")) {
             continue;
         }
-        QProgressBar *pogressBar = new QProgressBar;
-        pogressBar->setValue(data["marker-levels"].value<QList<int> >().at(i));
+        auto pogressBar = new QProgressBar;
+        pogressBar->setValue(data[KCUPS_MARKER_LEVELS].value<QList<int> >().at(i));
         pogressBar->setTextVisible(false);
         pogressBar->setMaximumHeight(15);
         QPalette palette = pogressBar->palette();
         palette.setColor(QPalette::Active,
                          QPalette::Highlight,
-                         QColor(data["marker-colors"].toStringList().at(i)));
+                         QColor(data[KCUPS_MARKER_COLORS].toStringList().at(i)));
         palette.setColor(QPalette::Inactive,
                          QPalette::Highlight,
-                         QColor(data["marker-colors"].toStringList().at(i)).lighter());
+                         QColor(data[KCUPS_MARKER_COLORS].toStringList().at(i)).lighter());
         pogressBar->setPalette(palette);
-        QLabel *label = new QLabel(data["marker-names"].toStringList().at(i), this);
+        auto label = new QLabel(data[KCUPS_MARKER_NAMES].toStringList().at(i), this);
         ui->formLayout->addRow(label, pogressBar);
     }
 }
@@ -235,8 +230,8 @@ void PrinterDescription::on_actionPrintTestPage_triggered(bool checked)
 {
     Q_UNUSED(checked)
 
-    KCupsRequest *request = new KCupsRequest;
-    connect(request, SIGNAL(finished()), this, SLOT(requestFinished()));
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, &PrinterDescription::requestFinished);
     request->printTestPage(m_destName, m_isClass);
 }
 
@@ -244,23 +239,22 @@ void PrinterDescription::on_actionCleanPrintHeads_triggered(bool checked)
 {
     Q_UNUSED(checked)
 
-    KCupsRequest *request = new KCupsRequest;
-    connect(request, SIGNAL(finished()), this, SLOT(requestFinished()));
-    request->printCommand(m_destName, "Clean all", i18n("Clean Print Heads"));
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, &PrinterDescription::requestFinished);
+    request->printCommand(m_destName, QLatin1String("Clean all"), i18n("Clean Print Heads"));
 }
 
 void PrinterDescription::on_actionPrintSelfTestPage_triggered(bool checked)
 {
     Q_UNUSED(checked)
 
-    KCupsRequest *request = new KCupsRequest;
-    connect(request, SIGNAL(finished()), this, SLOT(requestFinished()));
-    request->printCommand(m_destName, "PrintSelfTestPage", i18n("Print Self-Test Page"));
+    auto request = new KCupsRequest;
+    connect(request, &KCupsRequest::finished, this, &PrinterDescription::requestFinished);
+    request->printCommand(m_destName, QLatin1String("PrintSelfTestPage"), i18n("Print Self-Test Page"));
 }
 
-void PrinterDescription::requestFinished()
+void PrinterDescription::requestFinished(KCupsRequest *request)
 {
-    KCupsRequest *request = qobject_cast<KCupsRequest*>(sender());
     if (request && request->hasError()) {
         ui->errorMessage->setText(i18n("Failed to perform request: %1", request->errorMsg()));
         ui->errorMessage->animatedShow();
@@ -281,5 +275,7 @@ void PrinterDescription::enableShareCheckBox(bool enable)
 
 void PrinterDescription::on_configurePB_clicked()
 {
-    QProcess::startDetached("configure-printer", {m_destName});
+    QProcess::startDetached(QLatin1String("configure-printer"), {m_destName});
 }
+
+#include "moc_PrinterDescription.cpp"
